@@ -95,8 +95,8 @@ bool KGrEditor::createLevel (int pGameIndex)
 
     // Clear the playfield.
     levelData.layout.resize (levelData.width * levelData.height);
-    for (i = 1; i <= levelData.width; i++) {
-	for (j = 1; j <= levelData.height; j++) {
+    for (i = 1; i <= levelData.width; ++i) {
+	for (j = 1; j <= levelData.height; ++j) {
             insertEditObj (i, j, FREE);
         }
     }
@@ -177,8 +177,8 @@ void KGrEditor::loadEditLevel (int lev)
     char obj;
 
     // Load the level.
-    for (i = 1; i <= levelData.width;  i++) {
-	for (j = 1; j <= levelData.height; j++) {
+    for (i = 1; i <= levelData.width;  ++i) {
+	for (j = 1; j <= levelData.height; ++j) {
             obj = d.layout [(j-1) * d.width + (i-1)];
             insertEditObj (i, j, obj);
 	}
@@ -188,9 +188,9 @@ void KGrEditor::loadEditLevel (int lev)
     // Retain the original language of the name and hint when editing,
     // but convert non-ASCII, UTF-8 substrings to Unicode (eg. Ã¼ to ü).
     levelName = (d.name.size() > 0) ?
-                QString::fromUtf8 ((const char *) d.name) : "";
+                QString::fromUtf8 (d.name) : QString();
     levelHint = (d.hint.size() > 0) ?
-                QString::fromUtf8 ((const char *) d.hint) : "";
+                QString::fromUtf8 (d.hint) : QString();
 
     scene->setTitle (getTitle());		// Show the level name.
 }
@@ -274,8 +274,8 @@ bool KGrEditor::saveLevelFile()
     }
 
     // Save the level - row by row.
-    for (j = 1; j <= levelData.height; j++) {
-        for (i = 1; i <= levelData.width; i++) {
+    for (j = 1; j <= levelData.height; ++j) {
+        for (i = 1; i <= levelData.width; ++i) {
             levelFile.putChar (editableCell (i, j));
         }
     }
@@ -286,7 +286,7 @@ bool KGrEditor::saveLevelFile()
     QByteArray levelNameC = levelName.toUtf8();
     int len1 = levelNameC.length();
     if (len1 > 0) {
-        for (i = 0; i < len1; i++)
+        for (i = 0; i < len1; ++i)
             levelFile.putChar (levelNameC[i]);
         levelFile.putChar ('\n');			// Add a newline.
     }
@@ -299,7 +299,7 @@ bool KGrEditor::saveLevelFile()
     if (len2 > 0) {
         if (len1 <= 0)
             levelFile.putChar ('\n');		// Leave blank line for name.
-        for (i = 0; i < len2; i++) {
+        for (i = 0; i < len2; ++i) {
             ch = levelHintC[i];
             levelFile.putChar (ch);		// Copy the character.
         }
@@ -374,7 +374,7 @@ bool KGrEditor::moveLevelFile (int pGameIndex, int level)
     // Save the "fromN" file under a temporary name.
     filePath1 = getLevelFilePath (gameList.at (fromC), fromL);
     filePath2 = filePath1;
-    filePath2 = filePath2.append (".tmp");
+    filePath2 = filePath2.append (QStringLiteral(".tmp"));
     if (! KGrGameIO::safeRename (view, filePath1, filePath2)) {
         return false;
     }
@@ -780,7 +780,7 @@ bool KGrEditor::saveGameData (Owner o)
         return (false);
     }
 
-    filePath = userDataDir + "games.dat";
+    filePath = userDataDir + QStringLiteral("games.dat");
 
     QFile c (filePath);
 
@@ -799,14 +799,14 @@ bool KGrEditor::saveGameData (Owner o)
 
     for (KGrGameData * gData : qAsConst(gameList)) {
         if (gData->owner == o) {
-            line = QString ("%1 %2 %3 %4\n")
-                            .arg (gData->nLevels, 3, 10, QChar('0')) // int 00n
+            line = QStringLiteral ("%1 %2 %3 %4\n")
+                            .arg (gData->nLevels, 3, 10, QLatin1Char('0')) // int 00n
                             .arg (gData->rules)                      // char
                             .arg (gData->prefix)                     // QString
                             .arg (gData->name);                      // QString
             lineC = line.toUtf8();
             len = lineC.length();
-            for (i = 0; i < len; i++) {
+            for (i = 0; i < len; ++i) {
                 c.putChar (lineC.at (i));
             }
 
@@ -814,7 +814,7 @@ bool KGrEditor::saveGameData (Owner o)
             if (len > 0) {
                 QByteArray aboutC = gData->about;
                 len = aboutC.length();		// Might be longer now.
-                for (i = 0; i < len; i++) {
+                for (i = 0; i < len; ++i) {
                     ch = aboutC[i];
                     if (ch != '\n') {
                         c.putChar (ch);		// Copy the character.
@@ -842,7 +842,7 @@ QString KGrEditor::getTitle()
 
     // Set title string to "Game-name - NNN" or "Game-name - NNN - Level-name".
     KGrGameData * gameData = gameList.at(gameIndex);
-    QString levelNumber = QString::number(editLevel).rightJustified(3,'0');
+    QString levelNumber = QString::number(editLevel).rightJustified(3, QLatin1Char('0'));
 
     QString levelTitle = (levelName.length() <= 0)
                     ?
@@ -858,8 +858,8 @@ QString KGrEditor::getTitle()
 
 QString KGrEditor::getLevelFilePath (KGrGameData * gameData, int lev)
 {
-    QString filePath = userDataDir + "levels/" + gameData->prefix +
-                       QString::number(lev).rightJustified(3,'0') + ".grl";
+    QString filePath = userDataDir + QStringLiteral("levels/") + gameData->prefix +
+                       QString::number(lev).rightJustified(3, QLatin1Char('0')) + QStringLiteral(".grl");
     return (filePath);
 }
 
